==> ejc-cost-api-3.0.0-20221013.102326-138-sources.jar: com/ejianc/business/budget/vo/BudgetProjectProQuantityAndMnyVO.java <==
package com.ejianc.business.budget.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.Map;

/**
 * 项目预算Pro量价VO
 *
 * @author baipengyan
 * @version 1.0
 * @since JDK 1.8
 */
public class BudgetProjectProQuantityAndMnyVO extends BaseVO {
	private BigDecimal budgetTaxMny; // 预算总金额（含税）
	private BigDecimal budgetMny; // 预算总金额(无税)
	private BigDecimal indirectionTaxMny; // 间接费(含税)
	private BigDecimal indirectionMny; // 间接费（无税）
	private BigDecimal laborTaxMny; // 人工费（含税）
	private BigDecimal laborMny; // 人工费（无税）
	private BigDecimal materialTaxMny; // 材料费（含税）
	private BigDecimal materialMny; // 材料费（无税）
	private BigDecimal majorTaxMny; // 专业费（含税）
	private BigDecimal majorMny; // 专业费（无税）
	private BigDecimal mechanicalTaxMny; // 机械费(含税 )
	private BigDecimal mechanicalMny; // 机械费（无税）
	private Map<Long, BudgetProjectDetailProVO> detailProMap;

	public BigDecimal getBudgetTaxMny() {
		return budgetTaxMny;
	}

	public void setBudgetTaxMny(BigDecimal budgetTaxMny) {
		this.budgetTaxMny = budgetTaxMny;
	}

	public BigDecimal getBudgetMny() {
		return budgetMny;
	}

	public void setBudgetMny(BigDecimal budgetMny) {
		this.budgetMny = budgetMny;
	}

	public BigDecimal getIndirectionTaxMny() {
		return indirectionTaxMny;
	}

	public void setIndirectionTaxMny(BigDecimal indirectionTaxMny) {
		this.indirectionTaxMny = indirectionTaxMny;
	}

	public BigDecimal getIndirectionMny() {
		return indirectionMny;
	}

	public void setIndirectionMny(BigDecimal indirectionMny) {
		this.indirectionMny = indirectionMny;
	}

	public BigDecimal getLaborTaxMny() {
		return laborTaxMny;
	}

	public void setLaborTaxMny(BigDecimal laborTaxMny) {
		this.laborTaxMny = laborTaxMny;
	}

	public BigDecimal getLaborMny() {
		return laborMny;
	}

	public void setLaborMny(BigDecimal laborMny) {
		this.laborMny = laborMny;
	}

	public BigDecimal getMaterialTaxMny() {
		return materialTaxMny;
	}

	public void setMaterialTaxMny(BigDecimal materialTaxMny) {
		this.materialTaxMny = materialTaxMny;
	}

	public BigDecimal getMaterialMny() {
		return materialMny;
	}

	public void setMaterialMny(BigDecimal materialMny) {
		this.materialMny = materialMny;
	}

	public BigDecimal getMajorTaxMny() {
		return majorTaxMny;
	}

	public void setMajorTaxMny(BigDecimal majorTaxMny) {
		this.majorTaxMny = majorTaxMny;
	}

	public BigDecimal getMajorMny() {
		return majorMny;
	}

	public void setMajorMny(BigDecimal majorMny) {
		this.majorMny = majorMny;
	}

	public BigDecimal getMechanicalTaxMny() {
		return mechanicalTaxMny;
	}

	public void setMechanicalTaxMny(BigDecimal mechanicalTaxMny) {
		this.mechanicalTaxMny = mechanicalTaxMny;
	}

	public BigDecimal getMechanicalMny() {
		return mechanicalMny;
	}

	public void setMechanicalMny(BigDecimal mechanicalMny) {
		this.mechanicalMny = mechanicalMny;
	}

	public Map<Long, BudgetProjectDetailProVO> getDetailProMap() {
		return detailProMap;
	}

	public void setDetailProMap(Map<Long, BudgetProjectDetailProVO> detailProMap) {
		this.detailProMap = detailProMap;
	}
}

==> ejc-cost-api-3.0.0-20240306.075708-317-sources.jar: com/ejianc/business/budget/vo/BudgetProjectProQuantityAndMnyVO.java <==
package com.ejianc.business.budget.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.Map;

/**
 * 项目预算Pro量价VO
 *
 * @author baipengyan
 * @version 1.0
 * @since JDK 1.8
 */
public class BudgetProjectProQuantityAndMnyVO extends BaseVO {
	private BigDecimal budgetTaxMny = BigDecimal.ZERO; // 预算总金额（含税）
	private BigDecimal budgetMny = BigDecimal.ZERO; // 预算总金额(无税)
	private BigDecimal indirectionTaxMny = BigDecimal.ZERO; // 间接费(含税)
	private BigDecimal indirectionMny = BigDecimal.ZERO; // 间接费（无税）
	private BigDecimal laborTaxMny = BigDecimal.ZERO; // 人工费（含税）
	private BigDecimal laborMny = BigDecimal.ZERO; // 人工费（无税）
	private BigDecimal materialTaxMny = BigDecimal.ZERO; // 材料费（含税）
	private BigDecimal materialMny = BigDecimal.ZERO; // 材料费（无税）
	private BigDecimal majorTaxMny = BigDecimal.ZERO; // 专业费（含税）
	private BigDecimal majorMny = BigDecimal.ZERO; // 专业费（无税）
	private BigDecimal mechanicalTaxMny = BigDecimal.ZERO; // 机械费(含税 )
	private BigDecimal mechanicalMny = BigDecimal.ZERO; // 机械费（无税）
	private Map<Long, BudgetProjectDetailProVO> detailProMap;

	public BigDecimal getBudgetTaxMny() {
		return budgetTaxMny;
	}

	public void setBudgetTaxMny(BigDecimal budgetTaxMny) {
		this.budgetTaxMny = budgetTaxMny;
	}

	public BigDecimal getBudgetMny() {
		return budgetMny;
	}

	public void setBudgetMny(BigDecimal budgetMny) {
		this.budgetMny = budgetMny;
	}

	public BigDecimal getIndirectionTaxMny() {
		return indirectionTaxMny;
	}

	public void setIndirectionTaxMny(BigDecimal indirectionTaxMny) {
		this.indirectionTaxMny = indirectionTaxMny;
	}

	public BigDecimal getIndirectionMny() {
		return indirectionMny;
	}

	public void setIndirectionMny(BigDecimal indirectionMny) {
		this.indirectionMny = indirectionMny;
	}

	public BigDecimal getLaborTaxMny() {
		return laborTaxMny;
	}

	public void setLaborTaxMny(BigDecimal laborTaxMny) {
		this.laborTaxMny = laborTaxMny;
	}

	public BigDecimal getLaborMny() {
		return laborMny;
	}

	public void setLaborMny(BigDecimal laborMny) {
		this.laborMny = laborMny;
	}

	public BigDecimal getMaterialTaxMny() {
		return materialTaxMny;
	}

	public void setMaterialTaxMny(BigDecimal materialTaxMny) {
		this.materialTaxMny = materialTaxMny;
	}

	public BigDecimal getMaterialMny() {
		return materialMny;
	}

	public void setMaterialMny(BigDecimal materialMny) {
		this.materialMny = materialMny;
	}

	public BigDecimal getMajorTaxMny() {
		return majorTaxMny;
	}

	public void setMajorTaxMny(BigDecimal majorTaxMny) {
		this.majorTaxMny = majorTaxMny;
	}

	public BigDecimal getMajorMny() {
		return majorMny;
	}

	public void setMajorMny(BigDecimal majorMny) {
		this.majorMny = majorMny;
	}

	public BigDecimal getMechanicalTaxMny() {
		return mechanicalTaxMny;
	}

	public void setMechanicalTaxMny(BigDecimal mechanicalTaxMny) {
		this.mechanicalTaxMny = mechanicalTaxMny;
	}

	public BigDecimal getMechanicalMny() {
		return mechanicalMny;
	}

	public void setMechanicalMny(BigDecimal mechanicalMny) {
		this.mechanicalMny = mechanicalMny;
	}

	public Map<Long, BudgetProjectDetailProVO> getDetailProMap() {
		return detailProMap;
	}

	public void setDetailProMap(Map<Long, BudgetProjectDetailProVO> detailProMap) {
		this.detailProMap = detailProMap;
	}
}
